@@ -235,7 +235,8 @@ Minion::Backend::Pg - PostgreSQL backend
 
 L<Minion::Backend::Pg> is a backend for L<Minion> based on L<Mojo::Pg>. All
 necessary tables will be created automatically with a set of migrations named
-C<minion>.
+C<minion>. Note that this backend uses many bleeding edge features, so only
+the latest, stable version of PostgreSQL is fully supported.
 
 =head1 ATTRIBUTES
 
